@@ -11,7 +11,6 @@ import warnings
 import yaml
 
 import pytest
-from _pytest.resultlog import generic_path
 import github3
 
 # Import, or define, NullHandler
@@ -36,6 +35,30 @@ log.addHandler(NullHandler())
 GITHUB_COMPLETED_LABELS = []
 
 
+def generic_path(item):
+    chain = item.listchain()
+    gpath = [chain[0].name]
+    fspath = chain[0].fspath
+    fspart = False
+    for node in chain[1:]:
+        newfspath = node.fspath
+        if newfspath == fspath:
+            if fspart:
+                gpath.append(":")
+                fspart = False
+            else:
+                gpath.append(".")
+        else:
+            gpath.append("/")
+            fspart = True
+        name = node.name
+        if name[0] in "([":
+            gpath.pop()
+        gpath.append(name)
+        fspath = newfspath
+    return "".join(gpath)
+
+
 def pytest_addoption(parser):
     """Add options to control github integration."""
     group = parser.getgroup('pytest-github')
@@ -240,7 +263,6 @@ class GitHubPytestPlugin(object):
             errstr = "Malformed github issue URL: '%s'" % url
             raise Exception(errstr)
 
-
     def pytest_runtest_setup(self, item):
         """Handle github marker by calling xfail or skip, as needed."""
         log.debug("pytest_runtest_setup() called")
@@ -259,7 +281,7 @@ class GitHubPytestPlugin(object):
             param_marker = item.get_closest_marker('parametrize')
             param_marker_ids = []
             if param_marker:
-                param_marker_ids = param_marker.kwargs.get('ids', [])
+                param_marker_ids = param_marker.kwargs.get('ids', [])  # noqa F841
             current_test_id = item.callspec.id
 
             if current_test_id not in github_marker_ids:
